'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.GReference = void 0;
const json_1 = require("./json");
const types_1 = require("./types");
const htmlUtils_1 = require("./util/htmlUtils");
const mdUtils_1 = require("./util/mdUtils");
class GReference {
    constructor(machineType, variant) {
        this.machineType = machineType;
        this.variant = variant;
        machineType !== undefined ? (this._machineType = machineType) : (this._machineType = types_1.MachineTypes.Mill);
        variant !== undefined ? (this._variant = variant) : undefined;
        this._buildReference();
    }
    _buildReference() {
        this._gcode = (0, json_1.loadJSON)(types_1.CodeTypes.G, this._machineType, this._variant);
        this._mcode = (0, json_1.loadJSON)(types_1.CodeTypes.M, this._machineType, this._variant);
    }
    _cleanCode(code) {
        if (code.length === 2) {
            code = `${code[0]}0${code.substring(1)}`;
        }
        return code;
    }
    getType() {
        return this._machineType;
    }
    setType(type) {
        if (this._machineType === type) {
            return;
        }
        else {
            this._machineType = type;
            this._buildReference();
        }
    }
    isVariant() {
        if (this._variant) {
            return true;
        }
        else {
            return false;
        }
    }
    getVariant() {
        return this._variant;
    }
    setVariant(variant) {
        if (this._variant === variant) {
            return;
        }
        else {
            this._variant = variant;
            this._buildReference();
        }
    }
    removeVariant() {
        this._variant = undefined;
        this._buildReference();
    }
    get(code) {
        code = this._cleanCode(code);
        if (code[0].toUpperCase() === 'G') {
            if (this._gcode) {
                const codes = this._gcode.codes;
                if (code in codes) {
                    return codes[code];
                }
                else {
                    return undefined;
                }
            }
            else {
                return undefined;
            }
        }
        else if (code[0].toUpperCase() === 'M') {
            if (this._mcode) {
                const codes = this._mcode.codes;
                if (code in codes) {
                    return codes[code];
                }
                else {
                    return undefined;
                }
            }
            else {
                return undefined;
            }
        }
        return undefined;
    }
    getDesc(code) {
        return this.get(code)?.desc;
    }
    getShortDesc(code) {
        return this.get(code)?.shortDesc;
    }
    getParams(code, req) {
        const c = this.get(code);
        if (c) {
            if (req) {
                const params = {};
                const p = c.parameters;
                for (const key in p) {
                    if (Object.prototype.hasOwnProperty.call(p, key)) {
                        if (!p[key].optional) {
                            params[key] = p[key];
                        }
                    }
                }
                return params;
            }
            else {
                return c.parameters;
            }
        }
        else {
            return undefined;
        }
    }
    getAllCodes(codeType) {
        if (codeType === types_1.CodeTypes.G) {
            return this._gcode?.codes;
        }
        else if (codeType === types_1.CodeTypes.M) {
            return this._mcode?.codes;
        }
        return undefined;
    }
    getCodeAsMarkdown(code) {
        const c = this.get(code);
        if (c) {
            return mdUtils_1.MDUtils.codeToMarkdown(code, c);
        }
        else {
            return undefined;
        }
    }
    getAllCodesAsMarkdown(codeType) {
        if (codeType === types_1.CodeTypes.G && this._gcode) {
            return mdUtils_1.MDUtils.allCodesToMarkdown(this._gcode);
        }
        else if (codeType === types_1.CodeTypes.M && this._mcode) {
            return mdUtils_1.MDUtils.allCodesToMarkdown(this._mcode);
        }
        return undefined;
    }
    getCodeAsHTML(code, partial = true) {
        const c = this.get(code);
        if (c) {
            return htmlUtils_1.HTMLUtils.codeToHTML(code, c, partial);
        }
        else {
            return undefined;
        }
    }
    getAllCodesAsHTML(codeType, partial = true) {
        if (codeType === types_1.CodeTypes.G && this._gcode) {
            return htmlUtils_1.HTMLUtils.allCodesToHTML(this._gcode, partial);
        }
        else if (codeType === types_1.CodeTypes.M && this._mcode) {
            return htmlUtils_1.HTMLUtils.allCodesToHTML(this._mcode, partial);
        }
        return undefined;
    }
}
exports.GReference = GReference;
//# sourceMappingURL=gReference.js.map